@@ -1,5 +1,3 @@
-import sys
-
 import os.path as osp
 
 author = "Rocky Bernstein"
@@ -21,6 +19,10 @@ classifiers = [
     "Programming Language :: Python :: 3.7",
     "Programming Language :: Python :: 3.8",
     "Programming Language :: Python :: 3.9",
+    "Programming Language :: Python :: 3.10",
+    "Programming Language :: Python :: 3.11",
+    "Programming Language :: Python :: 3.12",
+    "Programming Language :: Python :: 3.13",
 ]
 
 def get_srcdir():
